# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.config import Config

class TestConfig(unittest.TestCase):
    """Config unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Config:
        """Test Config
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Config`
        """
        model = Config()
        if include_optional:
            return Config(
                error_reporting = authentik_client.models.error_reporting_config.ErrorReportingConfig(
                    enabled = True, 
                    sentry_dsn = '', 
                    environment = '', 
                    send_pii = True, 
                    traces_sample_rate = 1.337, ),
                capabilities = [
                    'can_save_media'
                    ],
                cache_timeout = 56,
                cache_timeout_flows = 56,
                cache_timeout_policies = 56
            )
        else:
            return Config(
                error_reporting = authentik_client.models.error_reporting_config.ErrorReportingConfig(
                    enabled = True, 
                    sentry_dsn = '', 
                    environment = '', 
                    send_pii = True, 
                    traces_sample_rate = 1.337, ),
                capabilities = [
                    'can_save_media'
                    ],
                cache_timeout = 56,
                cache_timeout_flows = 56,
                cache_timeout_policies = 56,
        )
        """

    def testConfig(self):
        """Test Config"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
